==> create-node-react-app-1.0.27.tgz: package/my-app/src/resolvers/UserResolver.ts <==
import { Authorized, Ctx, FieldResolver, Query, Resolver, Root, Mutation, Arg, ObjectType, Field } from 'type-graphql'
import jwt from 'jsonwebtoken'
import { database } from '../server/initDatabaseClient'
import { createCipheriv, randomBytes, scryptSync } from 'crypto'
import { User } from '../entities'

const cipher = createCipheriv('aes-256-cbc', scryptSync(process.env.JWT_AUTH_SECRET, 'salt', 32), randomBytes(16))

@ObjectType()
class AuthResponse {
  @Field(() => User) user: User
  @Field() accessToken: string
}

@Resolver(User)
class UserResolver {
  @Authorized()
  @Query(() => User)
  async me(@Ctx() { user }: { user?: { uid: string } }) {
    return user
  }

  @Mutation(() => AuthResponse)
  async login(@Arg('email') email: string, @Arg('password') password: string) {
    const { password: hide, ...user } = database.collection<User>('user').findOne({ email, emailVerified: true, password: cipher.update(password).toString('hex') })
    const accessToken = jwt.sign(user, process.env.JWT_AUTH_SECRET)
    return { user, accessToken }
  }

  @Mutation(() => Boolean)
  async signup(@Arg('email') email: string) {
    try {
      const password = cipher.update(randomBytes(32)).toString('hex')
      const user = { email, password, emailVerified: false }
      const { insertedId } = await database.collection<User>('user').insertOne(user)
      const uid = insertedId.toString()
      await database.collection<User>('user').update({ _id: insertedId }, { $set: { uid } })
      const resetToken = jwt.sign({ uid, ...user }, process.env.JWT_AUTH_SECRET)
      // TODO: send verification email
      console.log(`/reset-password?token=${resetToken}`)
      return true
    } catch (e) {
      console.error(e)
      return false
    }
  }

  @Mutation(() => Boolean)
  async resetPassword(@Arg('password') password: string, @Arg('token') token: string) {
    try {
      const { uid } = jwt.verify(token, process.env.JWT_AUTH_SECRET) as User
      cipher.update(password).toString('hex')
      database.collection('user').update({ uid }, { password, emailVerified: true })
      return true
    } catch (e) {
      console.error(e)
      return false
    }
  }

  @FieldResolver(() => String)
  fullName(@Root() user: User) {
    return `${user.firstName} ${user.lastName}`
  }
}

export default UserResolver

==> create-node-react-app-1.0.29.tgz: package/my-app/src/resolvers/UserResolver.ts <==
import { Authorized, Ctx, FieldResolver, Query, Resolver, Root, Mutation, Arg, ObjectType, Field } from 'type-graphql'
import jwt from 'jsonwebtoken'
import { database } from '../server/initDatabaseClient'
import { randomBytes } from 'crypto'
import { encrypt } from '../utils'
import { User } from '../entities'

@ObjectType()
class AuthResponse {
  @Field(() => User) user: User
  @Field() accessToken: string
}

@Resolver(User)
class UserResolver {
  @Authorized()
  @Query(() => User)
  async me(@Ctx() { user }: { user?: { uid: string } }) {
    return user
  }

  @Mutation(() => AuthResponse)
  async login(@Arg('email') email: string, @Arg('password') password: string) {
    const { password: compare, ...user } = await database.collection<User>('user').findOne({ email, emailVerified: true })
    if (encrypt(password) !== compare) {
      throw new Error('Invalid password')
    }
    const accessToken = jwt.sign(user, process.env.JWT_AUTH_SECRET)
    return { user, accessToken }
  }

  @Mutation(() => Boolean)
  async signup(@Arg('email') email: string) {
    try {
      const password = encrypt(randomBytes(32).toString('utf-8'))
      const user = { email, password, emailVerified: false }
      const { insertedId } = await database.collection<User>('user').insertOne(user)
      const uid = insertedId.toString()
      await database.collection<User>('user').updateOne({ _id: insertedId }, { $set: { uid } })
      const resetToken = jwt.sign({ uid, ...user }, process.env.JWT_AUTH_SECRET)
      // TODO: send verification email
      console.log(`/reset-password?token=${resetToken}`)
      return true
    } catch (e) {
      console.error(e)
      return false
    }
  }

  @Mutation(() => Boolean)
  async resetPassword(@Arg('password') password: string, @Arg('token') token: string) {
    try {
      const { uid } = jwt.verify(token, process.env.JWT_AUTH_SECRET) as User
      await database.collection('user').updateOne({ uid }, { $set: { password: encrypt(password), emailVerified: true } })
      return true
    } catch (e) {
      console.error(e)
      return false
    }
  }

  @FieldResolver(() => String)
  fullName(@Root() user: User) {
    return `${user.firstName} ${user.lastName}`
  }
}

export default UserResolver
